from ..shared.display import display_error


def show_command_not_found():
    display_error("Command not found.")
